import { Commitment, Connection, RpcResponseAndContext, SimulatedTransactionResponse, Transaction, TransactionConfirmationStatus, TransactionSignature } from '@solana/web3.js';
import { BlockHeightStrategy, TimeStrategy, TransactionInstructionWithType, WalletSigner } from './types';
/**
 * waits for transaction confirmation
 * @param timeoutStrategy can be TimeStrategy: pure time based timeout or BlockHeightStrategy: blockheight pool strategy
 */
export declare const awaitTransactionSignatureConfirmation: ({ txid, confirmLevel, connection, timeoutStrategy, }: {
    txid: TransactionSignature;
    confirmLevel: TransactionConfirmationStatus;
    connection: Connection;
    timeoutStrategy: TimeStrategy | BlockHeightStrategy;
}) => Promise<unknown>;
/**
 * send and waits for transaction to confirm
 * @param postSendTxCallback call back that will fire after sending tx before waiting for tx to be confirmed.
 */
export declare const sendAndConfirmSignedTransaction: ({ signedTransaction, confirmLevel, connection, postSendTxCallback, timeoutStrategy, }: {
    signedTransaction: Transaction;
    connection: Connection;
    confirmLevel?: TransactionConfirmationStatus | undefined;
    postSendTxCallback?: (({ txid }: {
        txid: string;
    }) => void) | undefined;
    timeoutStrategy: TimeStrategy | BlockHeightStrategy;
}) => Promise<string>;
/**
 * sign and send array of transactions in desired batches with different styles of send for each array
 */
export declare const sendSignAndConfirmTransactions: ({ connection, wallet, TransactionInstructions, timeoutStrategy, }: {
    connection: Connection;
    wallet: WalletSigner;
    TransactionInstructions: TransactionInstructionWithType[];
    timeoutStrategy: BlockHeightStrategy;
}) => Promise<void>;
/** Copy of Connection.simulateTransaction that takes a commitment parameter. */
export declare function simulateTransaction(connection: Connection, transaction: Transaction, commitment: Commitment): Promise<RpcResponseAndContext<SimulatedTransactionResponse>>;
